@@ -804,38 +804,28 @@ def set_max_saved_sessions(max_sessions: int):
     set_config_value("max_saved_sessions", str(max_sessions))
 
 
-def get_diff_highlight_style() -> str:
-    """
-    Get the diff highlight style preference.
-    Options: 'text' (plain text, no highlighting), 'highlighted' (intelligent color pairs)
-    Returns 'highlighted' if not set or invalid.
-    """
-    val = get_value("diff_highlight_style")
-    if val and val.lower() in ["text", "highlighted"]:
-        return val.lower()
-    return "text"  # Default to intelligent highlighting
-
-
 def set_diff_highlight_style(style: str):
     """Set the diff highlight style.
 
+    Note: Text mode has been removed. This function is kept for backwards compatibility
+    but does nothing. All diffs use beautiful syntax highlighting now!
+
     Args:
-        style: 'text' for plain text diffs, 'highlighted' for intelligent color pairs
+        style: Ignored (always uses 'highlight' mode)
     """
-    if style.lower() not in ["text", "highlighted"]:
-        raise ValueError("diff_highlight_style must be 'text' or 'highlighted'")
-    set_config_value("diff_highlight_style", style.lower())
+    # Do nothing - we always use highlight mode now!
+    pass
 
 
 def get_diff_addition_color() -> str:
     """
     Get the base color for diff additions.
-    Default: green
+    Default: darker green
     """
-    val = get_value("diff_addition_color")
+    val = get_value("highlight_addition_color")
     if val:
         return val
-    return "sea_green1"  # Default to green
+    return "#0b1f0b"  # Default to darker green
 
 
 def set_diff_addition_color(color: str):
@@ -844,18 +834,18 @@ def set_diff_addition_color(color: str):
     Args:
         color: Rich color markup (e.g., 'green', 'on_green', 'bright_green')
     """
-    set_config_value("diff_addition_color", color)
+    set_config_value("highlight_addition_color", color)
 
 
 def get_diff_deletion_color() -> str:
     """
     Get the base color for diff deletions.
-    Default: orange1
+    Default: wine
     """
-    val = get_value("diff_deletion_color")
+    val = get_value("highlight_deletion_color")
     if val:
         return val
-    return "orange1"  # Default to orange1
+    return "#390e1a"  # Default to wine
 
 
 def set_diff_deletion_color(color: str):
@@ -864,67 +854,7 @@ def set_diff_deletion_color(color: str):
     Args:
         color: Rich color markup (e.g., 'orange1', 'on_bright_yellow', 'red')
     """
-    set_config_value("diff_deletion_color", color)
-
-
-def _emit_diff_style_example():
-    """Emit a small diff example showing the current style configuration."""
-
-    try:
-        from code_puppy.messaging import emit_info
-        from code_puppy.tools.file_modifications import _colorize_diff
-
-        # Create a simple diff example
-        example_diff = """--- a/example.txt
-+++ b/example.txt
-@@ -1,3 +1,4 @@
- line 1
--old line 2
-+new line 2
- line 3
-+added line 4"""
-
-        style = get_diff_highlight_style()
-        add_color = get_diff_addition_color()
-        del_color = get_diff_deletion_color()
-
-        # Get the actual color pairs being used
-        from code_puppy.tools.file_modifications import _get_optimal_color_pair
-
-        add_fg, add_bg = _get_optimal_color_pair(add_color, "green")
-        del_fg, del_bg = _get_optimal_color_pair(del_color, "orange1")
-
-        emit_info("\n🎨 [bold]Diff Style Updated![/bold]")
-        emit_info(f"Style: {style}", highlight=False)
-
-        if style == "highlighted":
-            # Show the actual color pairs being used
-            emit_info(
-                f"Additions: {add_fg} on {add_bg} (requested: {add_color})",
-                highlight=False,
-            )
-            emit_info(
-                f"Deletions: {del_fg} on {del_bg} (requested: {del_color})",
-                highlight=False,
-            )
-        else:
-            emit_info(f"Additions: {add_color} (plain text mode)", highlight=False)
-            emit_info(f"Deletions: {del_color} (plain text mode)", highlight=False)
-        emit_info(
-            "\n[bold cyan]── DIFF EXAMPLE ───────────────────────────────────[/bold cyan]"
-        )
-
-        # Show the colored example
-        colored_example = _colorize_diff(example_diff)
-        emit_info(colored_example, highlight=False)
-
-        emit_info(
-            "[bold cyan]───────────────────────────────────────────────[/bold cyan]\n"
-        )
-
-    except Exception:
-        # Fail silently if we can't emit the example
-        pass
+    set_config_value("highlight_deletion_color", color)
 
 
 def get_current_autosave_id() -> str:
