@@ -11,11 +11,9 @@ from pydantic_ai import RunContext
 # Module-level helper functions (exposed for unit tests _and_ used as tools)
 # ---------------------------------------------------------------------------
 from code_puppy.messaging import (
-    emit_divider,
     emit_error,
     emit_info,
     emit_success,
-    emit_system_message,
     emit_warning,
 )
 from code_puppy.tools.common import generate_group_id
@@ -463,7 +461,6 @@ def _read_file(
         console_msg += f" [dim](lines {start_line}-{start_line + num_lines - 1})[/dim]"
     emit_info(console_msg, message_group=group_id)
 
-    emit_divider(message_group=group_id)
     if not os.path.exists(file_path):
         error_msg = f"File {file_path} does not exist"
         return ReadFileOutput(content=error_msg, num_tokens=0, error=error_msg)
@@ -521,7 +518,6 @@ def _grep(context: RunContext, search_string: str, directory: str = ".") -> Grep
         f"\n[bold white on blue] GREP [/bold white on blue] \U0001f4c2 [bold cyan]{directory}[/bold cyan] [dim]for '{search_string}'[/dim]",
         message_group=group_id,
     )
-    emit_divider(message_group=group_id)
 
     # Create a temporary ignore file with our ignore patterns
     ignore_file = None
@@ -612,10 +608,6 @@ def _grep(context: RunContext, search_string: str, directory: str = ".") -> Grep
                         # Limit to 50 matches total, same as original implementation
                         if len(matches) >= 50:
                             break
-                        emit_system_message(
-                            f"[green]Match:[/green] {file_path}:{line_number} - {line_content.strip()}",
-                            message_group=group_id,
-                        )
             except json.JSONDecodeError:
                 # Skip lines that aren't valid JSON
                 continue
@@ -626,8 +618,77 @@ def _grep(context: RunContext, search_string: str, directory: str = ".") -> Grep
                 message_group=group_id,
             )
         else:
+            # Check if verbose output is enabled
+            from collections import defaultdict
+
+            from code_puppy.config import get_grep_output_verbose
+
+            matches_by_file = defaultdict(list)
+            for match in matches:
+                matches_by_file[match.file_path].append(match)
+
+            verbose = get_grep_output_verbose()
+
+            if verbose:
+                # Verbose mode: Show full output with line numbers and content
+                emit_info(
+                    "\n[bold cyan]─────────────────────────────────────────────────────[/bold cyan]",
+                    message_group=group_id,
+                )
+
+                for file_path in sorted(matches_by_file.keys()):
+                    file_matches = matches_by_file[file_path]
+                    emit_info(
+                        f"\n[bold white]📄 {file_path}[/bold white] [dim]({len(file_matches)} match{'es' if len(file_matches) != 1 else ''})[/dim]",
+                        message_group=group_id,
+                    )
+
+                    # Show each match with line number and content
+                    for match in file_matches:
+                        line = match.line_content
+                        search_term = search_string.split()[-1]
+                        if search_term.startswith("-"):
+                            search_term = (
+                                search_string.split()[0]
+                                if search_string.split()
+                                else search_string
+                            )
+
+                        # Case-insensitive highlighting
+                        import re
+
+                        highlighted_line = (
+                            re.sub(
+                                f"({re.escape(search_term)})",
+                                r"[bold yellow on black]\1[/bold yellow on black]",
+                                line,
+                                flags=re.IGNORECASE,
+                            )
+                            if search_term and not search_term.startswith("-")
+                            else line
+                        )
+
+                        emit_info(
+                            f"  [bold cyan]{match.line_number:4d}[/bold cyan] │ {highlighted_line}",
+                            message_group=group_id,
+                        )
+
+                emit_info(
+                    "\n[bold cyan]─────────────────────────────────────────────────────[/bold cyan]",
+                    message_group=group_id,
+                )
+            else:
+                # Concise mode (default): Show only file summaries
+                emit_info("", message_group=group_id)
+                for file_path in sorted(matches_by_file.keys()):
+                    file_matches = matches_by_file[file_path]
+                    emit_info(
+                        f"[dim]📄 {file_path} ({len(file_matches)} match{'es' if len(file_matches) != 1 else ''})[/dim]",
+                        message_group=group_id,
+                    )
+
             emit_success(
-                f"Found {len(matches)} match(es) for '{search_string}' in {directory}",
+                f"✓ Found [bold]{len(matches)}[/bold] match{'es' if len(matches) != 1 else ''} across [bold]{len(matches_by_file)}[/bold] file{'s' if len(matches_by_file) != 1 else ''}",
                 message_group=group_id,
             )
 
