@@ -9,12 +9,10 @@ from rich.console import Group
 from rich.markdown import Markdown
 from rich.syntax import Syntax
 from rich.text import Text
-from textual import on
 from textual.containers import Vertical, VerticalScroll
 from textual.widgets import Static
 
-from ..models import ChatMessage, MessageType
-from .copy_button import CopyButton
+from ..models import ChatMessage, MessageCategory, MessageType, get_message_category
 
 
 class ChatView(VerticalScroll):
@@ -22,148 +20,141 @@ class ChatView(VerticalScroll):
 
     DEFAULT_CSS = """
     ChatView {
-        background: $background;
-        scrollbar-background: $primary;
-        scrollbar-color: $accent;
+        background: $surface;
+        scrollbar-background: $panel;
+        scrollbar-color: $primary;
+        scrollbar-color-hover: $primary-lighten-1;
+        scrollbar-color-active: $primary-darken-1;
         margin: 0 0 1 0;
-        padding: 0;
+        padding: 1 2;
     }
 
     .user-message {
-        background: $primary-darken-3;
-        color: #ffffff;
-        margin: 0 0 1 0;
-        margin-top: 0;
-        padding: 1;
-        padding-top: 1;
+        background: $primary-background;
+        color: $text;
+        margin: 1 0 1 0;
+        padding: 1 2;
+        height: auto;
         text-wrap: wrap;
-        border: none;
-        border-left: thick $accent;
+        border: tall $primary;
+        border-title-align: left;
         text-style: bold;
     }
 
     .agent-message {
-        background: transparent;
-        color: #f3f4f6;
-        margin: 0 0 1 0;
-        margin-top: 0;
-        padding: 0;
-        padding-top: 0;
+        background: $panel;
+        color: $text;
+        margin: 1 0 1 0;
+        padding: 1 2;
+        height: auto;
         text-wrap: wrap;
-        border: none;
+        border: round $panel-lighten-2;
     }
 
     .system-message {
-        background: transparent;
-        color: #d1d5db;
-        margin: 0 0 1 0;
-        margin-top: 0;
-        padding: 0;
-        padding-top: 0;
+        background: $panel;
+        color: $text-muted;
+        margin: 1 0 1 0;
+        padding: 1 2;
+        height: auto;
         text-style: italic;
         text-wrap: wrap;
-        border: none;
+        border: dashed $panel-lighten-1;
     }
 
     .error-message {
-        background: transparent;
-        color: #fef2f2;
-        margin: 0 0 1 0;
-        margin-top: 0;
-        padding: 0;
-        padding-top: 0;
+        background: $error-darken-2;
+        color: $text;
+        margin: 1 0 1 0;
+        padding: 1 2;
+        height: auto;
         text-wrap: wrap;
-        border: none;
+        border: heavy $error;
+        border-title-align: left;
     }
 
     .agent_reasoning-message {
-        background: transparent;
-        color: #f3e8ff;
-        margin: 0 0 1 0;
-        margin-top: 0;
-        padding: 0;
-        padding-top: 0;
+        background: $accent-darken-2;
+        color: $accent-lighten-2;
+        margin: 1 0 1 0;
+        padding: 1 2;
+        height: auto;
         text-wrap: wrap;
         text-style: italic;
-        border: none;
+        border: round $accent;
     }
 
     .planned_next_steps-message {
-        background: transparent;
-        color: #f3e8ff;
-        margin: 0 0 1 0;
-        margin-top: 0;
-        padding: 0;
-        padding-top: 0;
+        background: $accent-darken-2;
+        color: $accent-lighten-3;
+        margin: 1 0 1 0;
+        padding: 1 2;
+        height: auto;
         text-wrap: wrap;
         text-style: italic;
-        border: none;
+        border: round $accent-lighten-1;
     }
 
     .agent_response-message {
-        background: transparent;
-        color: #f3e8ff;
-        margin: 0 0 1 0;
-        margin-top: 0;
-        padding: 0;
-        padding-top: 0;
+        background: $panel;
+        color: $text;
+        margin: 1 0 1 0;
+        padding: 1 2;
+        height: auto;
         text-wrap: wrap;
-        border: none;
+        border: double $accent;
     }
 
     .info-message {
-        background: transparent;
-        color: #d1fae5;
-        margin: 0 0 1 0;
-        margin-top: 0;
-        padding: 0;
-        padding-top: 0;
+        background: $success-darken-3;
+        color: $success-lighten-2;
+        margin: 1 0 1 0;
+        padding: 1 2;
+        height: auto;
         text-wrap: wrap;
-        border: none;
+        border: round $success;
     }
 
     .success-message {
-        background: #0d9488;
-        color: #d1fae5;
-        margin: 0 0 1 0;
-        margin-top: 0;
-        padding: 0;
-        padding-top: 0;
+        background: $success-darken-1;
+        color: $text;
+        margin: 1 0 1 0;
+        padding: 1 2;
+        height: auto;
         text-wrap: wrap;
-        border: none;
+        border: heavy $success;
+        border-title-align: center;
     }
 
     .warning-message {
-        background: #d97706;
-        color: #fef3c7;
-        margin: 0 0 1 0;
-        margin-top: 0;
-        padding: 0;
-        padding-top: 0;
+        background: $warning-darken-2;
+        color: $text;
+        margin: 1 0 1 0;
+        padding: 1 2;
+        height: auto;
         text-wrap: wrap;
-        border: none;
+        border: wide $warning;
+        border-title-align: left;
     }
 
     .tool_output-message {
-        background: #5b21b6;
-        color: #dbeafe;
-        margin: 0 0 1 0;
-        margin-top: 0;
-        padding: 0;
-        padding-top: 0;
+        background: $accent-darken-3;
+        color: $accent-lighten-2;
+        margin: 1 0 1 0;
+        padding: 1 2;
+        height: auto;
         text-wrap: wrap;
-        border: none;
+        border: round $accent-darken-1;
     }
 
     .command_output-message {
-        background: #9a3412;
-        color: #fed7aa;
-        margin: 0 0 1 0;
-        margin-top: 0;
-        padding: 0;
-        padding-top: 0;
+        background: $warning-darken-3;
+        color: $warning-lighten-2;
+        margin: 1 0 1 0;
+        padding: 1 2;
+        height: auto;
         text-wrap: wrap;
-        border: none;
+        border: solid $warning-darken-1;
     }
 
     .message-container {
@@ -172,18 +163,9 @@ class ChatView(VerticalScroll):
         width: 1fr;
     }
 
-    .copy-button-container {
-        margin: 0 0 1 0;
-        padding: 0 1;
-        width: 1fr;
-        height: auto;
-        align: left top;
-    }
-
     /* Ensure first message has no top spacing */
     ChatView > *:first-child {
         margin-top: 0;
-        padding-top: 0;
     }
     """
 
@@ -193,6 +175,33 @@ class ChatView(VerticalScroll):
         self.message_groups: dict = {}  # Track groups for visual grouping
         self.group_widgets: dict = {}  # Track widgets by group_id for enhanced grouping
         self._scroll_pending = False  # Track if scroll is already scheduled
+        self._last_message_category = None  # Track last message category for combining
+        self._last_widget = None  # Track the last widget created for combining
+        self._last_combined_message = (
+            None  # Track the actual message we're combining into
+        )
+
+    def _should_suppress_message(self, message: ChatMessage) -> bool:
+        """Check if a message should be suppressed based on user settings."""
+        from code_puppy.config import (
+            get_suppress_informational_messages,
+            get_suppress_thinking_messages,
+        )
+
+        category = get_message_category(message.type)
+
+        suppress_thinking = get_suppress_thinking_messages()
+        suppress_info = get_suppress_informational_messages()
+
+        # Check if thinking messages should be suppressed
+        if category == MessageCategory.THINKING and suppress_thinking:
+            return True
+
+        # Check if informational messages should be suppressed
+        if category == MessageCategory.INFORMATIONAL and suppress_info:
+            return True
+
+        return False
 
     def _render_agent_message_with_syntax(self, prefix: str, content: str):
         """Render agent message with proper syntax highlighting for code blocks."""
@@ -253,7 +262,6 @@ class ChatView(VerticalScroll):
         last_entry = group_widgets[-1]
         last_message = last_entry["message"]
         last_widget = last_entry["widget"]
-        copy_button = last_entry.get("copy_button")
 
         # Create a separator for different message types in the same group
         if message.type != last_message.type:
@@ -310,10 +318,6 @@ class ChatView(VerticalScroll):
             except Exception:
                 full_content = f"{prefix}{last_message.content}"
                 last_widget.update(Text(full_content))
-
-            # Update the copy button if it exists
-            if copy_button:
-                copy_button.update_text_to_copy(last_message.content)
         else:
             # Handle other message types
             # After the content concatenation above, content is always a string
@@ -336,9 +340,17 @@ class ChatView(VerticalScroll):
 
     def add_message(self, message: ChatMessage) -> None:
         """Add a new message to the chat view."""
+        # First check if this message should be suppressed
+        if self._should_suppress_message(message):
+            return  # Skip this message entirely
+
+        # Get message category for combining logic
+        message_category = get_message_category(message.type)
+
         # Enhanced grouping: check if we can append to ANY existing group
         if message.group_id is not None and message.group_id in self.group_widgets:
             self._append_to_existing_group(message)
+            self._last_message_category = message_category
             return
 
         # Old logic for consecutive grouping (keeping as fallback)
@@ -350,8 +362,100 @@ class ChatView(VerticalScroll):
             # This case should now be handled by _append_to_existing_group above
             # but keeping for safety
             self._append_to_existing_group(message)
+            self._last_message_category = message_category
             return
 
+        # Category-based combining - combine consecutive messages of same category
+
+        if (
+            self.messages
+            and self._last_message_category == message_category
+            and self._last_widget is not None  # Make sure we have a widget to update
+            and self._last_combined_message
+            is not None  # Make sure we have a message to combine into
+            and message_category
+            != MessageCategory.AGENT_RESPONSE  # Don't combine agent responses (they're complete answers)
+        ):
+            # SAME CATEGORY: Add to existing container
+            last_message = (
+                self._last_combined_message
+            )  # Use tracked message, not messages[-1]
+
+            # Create a separator for different message types within the same category
+            if message.type != last_message.type:
+                # Different types but same category - add a visual separator
+                separator = f"\n\n[dim]── {message.type.value.replace('_', ' ').title()} ──[/dim]\n"
+            else:
+                # Same type - simple spacing
+                separator = "\n\n"
+
+            # Append content to the last message
+            if hasattr(last_message.content, "__rich_console__") or hasattr(
+                message.content, "__rich_console__"
+            ):
+                # Handle Rich objects by converting to strings
+                from io import StringIO
+                from rich.console import Console
+
+                # Convert existing content to string
+                if hasattr(last_message.content, "__rich_console__"):
+                    string_io = StringIO()
+                    temp_console = Console(
+                        file=string_io, width=80, legacy_windows=False, markup=False
+                    )
+                    temp_console.print(last_message.content)
+                    existing_content = string_io.getvalue().rstrip("\n")
+                else:
+                    existing_content = str(last_message.content)
+
+                # Convert new content to string
+                if hasattr(message.content, "__rich_console__"):
+                    string_io = StringIO()
+                    temp_console = Console(
+                        file=string_io, width=80, legacy_windows=False, markup=False
+                    )
+                    temp_console.print(message.content)
+                    new_content = string_io.getvalue().rstrip("\n")
+                else:
+                    new_content = str(message.content)
+
+                # Combine as plain text
+                last_message.content = existing_content + separator + new_content
+            else:
+                # Both are strings, safe to concatenate
+                last_message.content += separator + message.content
+
+            # Update the tracked widget with the combined content
+            if self._last_widget is not None:
+                try:
+                    # Update the widget with the new combined content
+                    self._last_widget.update(Text.from_markup(last_message.content))
+                    # Force layout recalculation so the container grows
+                    self._last_widget.refresh(layout=True)
+                except Exception:
+                    # If markup parsing fails, fall back to plain text
+                    try:
+                        self._last_widget.update(Text(last_message.content))
+                        # Force layout recalculation so the container grows
+                        self._last_widget.refresh(layout=True)
+                    except Exception:
+                        # If update fails, create a new widget instead
+                        pass
+
+            # Add to messages list but don't create a new widget
+            self.messages.append(message)
+            # Refresh the entire view to ensure proper layout
+            self.refresh(layout=True)
+            self._schedule_scroll()
+            return
+
+        # DIFFERENT CATEGORY: Create new container
+        # Reset tracking so we don't accidentally update the wrong widget
+        if self._last_message_category != message_category:
+            self._last_widget = None
+            self._last_message_category = None
+            self._last_combined_message = None
+
         # Add to messages list
         self.messages.append(message)
 
@@ -377,6 +481,12 @@ class ChatView(VerticalScroll):
             message_widget = Static(Text(formatted_content), classes=css_class)
             # User messages are not collapsible - mount directly
             self.mount(message_widget)
+            # Track this widget for potential combining
+            self._last_widget = message_widget
+            # Track the category of this message for future combining
+            self._last_message_category = message_category
+            # Track the actual message for combining
+            self._last_combined_message = message
             # Auto-scroll to bottom
             self._schedule_scroll()
             return
@@ -431,40 +541,33 @@ class ChatView(VerticalScroll):
                 full_content = f"{prefix}{content}"
                 message_widget = Static(Text(full_content), classes=css_class)
 
-            # Try to create copy button - use simpler approach
-            try:
-                # Create copy button for agent responses
-                copy_button = CopyButton(content)  # Copy the raw content without prefix
+            # Make message selectable for easy copying
+            message_widget.can_focus = False  # Don't interfere with navigation
 
-                # Mount the message first
-                self.mount(message_widget)
+            # Mount the message
+            self.mount(message_widget)
 
-                # Then mount the copy button directly
-                self.mount(copy_button)
+            # Track this widget for potential combining
+            self._last_widget = message_widget
+            # Track the category of this message for future combining
+            self._last_message_category = message_category
+            # Track the actual message for combining
+            self._last_combined_message = message
 
-                # Track both the widget and copy button for group-based updates
-                if message.group_id:
-                    if message.group_id not in self.group_widgets:
-                        self.group_widgets[message.group_id] = []
-                    self.group_widgets[message.group_id].append(
-                        {
-                            "message": message,
-                            "widget": message_widget,
-                            "copy_button": copy_button,
-                        }
-                    )
+            # Track widget for group-based updates
+            if message.group_id:
+                if message.group_id not in self.group_widgets:
+                    self.group_widgets[message.group_id] = []
+                self.group_widgets[message.group_id].append(
+                    {
+                        "message": message,
+                        "widget": message_widget,
+                    }
+                )
 
-                # Auto-scroll to bottom with refresh to fix scroll bar issues (debounced)
-                self._schedule_scroll()
-                return  # Early return only if copy button creation succeeded
-
-            except Exception as e:
-                # If copy button creation fails, fall back to normal message display
-                # Log the error but don't let it prevent the message from showing
-                import sys
-
-                print(f"Warning: Copy button creation failed: {e}", file=sys.stderr)
-                # Continue to normal message mounting below
+            # Auto-scroll to bottom with refresh to fix scroll bar issues (debounced)
+            self._schedule_scroll()
+            return
         elif message.type == MessageType.INFO:
             prefix = "INFO: "
             content = f"{prefix}{message.content}"
@@ -492,6 +595,9 @@ class ChatView(VerticalScroll):
 
         self.mount(message_widget)
 
+        # Track this widget for potential combining
+        self._last_widget = message_widget
+
         # Track the widget for group-based updates
         if message.group_id:
             if message.group_id not in self.group_widgets:
@@ -500,45 +606,31 @@ class ChatView(VerticalScroll):
                 {
                     "message": message,
                     "widget": message_widget,
-                    "copy_button": None,  # Will be set if created
                 }
             )
 
         # Auto-scroll to bottom with refresh to fix scroll bar issues (debounced)
         self._schedule_scroll()
 
+        # Track the category of this message for future combining
+        self._last_message_category = message_category
+        # Track the actual message for combining (use the message we just added)
+        self._last_combined_message = self.messages[-1] if self.messages else None
+
     def clear_messages(self) -> None:
         """Clear all messages from the chat view."""
         self.messages.clear()
         self.message_groups.clear()  # Clear groups too
         self.group_widgets.clear()  # Clear widget tracking too
-        # Remove all message widgets (Static widgets, CopyButtons, and any Vertical containers)
+        self._last_message_category = None  # Reset category tracking
+        self._last_widget = None  # Reset widget tracking
+        self._last_combined_message = None  # Reset combined message tracking
+        # Remove all message widgets (Static widgets and any Vertical containers)
         for widget in self.query(Static):
             widget.remove()
-        for widget in self.query(CopyButton):
-            widget.remove()
         for widget in self.query(Vertical):
             widget.remove()
 
-    @on(CopyButton.CopyCompleted)
-    def on_copy_completed(self, event: CopyButton.CopyCompleted) -> None:
-        """Handle copy button completion events."""
-        if event.success:
-            # Could add a temporary success message or visual feedback
-            # For now, the button itself provides visual feedback
-            pass
-        else:
-            # Show error message in chat if copy failed
-            from datetime import datetime, timezone
-
-            error_message = ChatMessage(
-                id=f"copy_error_{datetime.now(timezone.utc).timestamp()}",
-                type=MessageType.ERROR,
-                content=f"Failed to copy to clipboard: {event.error}",
-                timestamp=datetime.now(timezone.utc),
-            )
-            self.add_message(error_message)
-
     def _schedule_scroll(self) -> None:
         """Schedule a scroll operation, avoiding duplicate calls."""
         if not self._scroll_pending:
